import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
/**
 * The provider type for the postgresql package. By default, resources use package-wide configuration
 * settings, however an explicit `Provider` instance may be created and passed during resource
 * construction to achieve fine-grained programmatic control over provider settings. See the
 * [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
 */
export declare class Provider extends pulumi.ProviderResource {
    /**
     * Returns true if the given object is an instance of Provider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Provider;
    /**
     * AWS profile to use for IAM auth
     */
    readonly awsRdsIamProfile: pulumi.Output<string | undefined>;
    /**
     * AWS region to use for IAM auth
     */
    readonly awsRdsIamRegion: pulumi.Output<string | undefined>;
    readonly azureTenantId: pulumi.Output<string | undefined>;
    /**
     * The name of the database to connect to in order to conenct to (defaults to `postgres`).
     */
    readonly database: pulumi.Output<string | undefined>;
    /**
     * Database username associated to the connected user (for user name maps)
     */
    readonly databaseUsername: pulumi.Output<string | undefined>;
    /**
     * Specify the expected version of PostgreSQL.
     */
    readonly expectedVersion: pulumi.Output<string | undefined>;
    /**
     * Service account to impersonate when using GCP IAM authentication.
     */
    readonly gcpIamImpersonateServiceAccount: pulumi.Output<string | undefined>;
    /**
     * Name of PostgreSQL server address to connect to
     */
    readonly host: pulumi.Output<string | undefined>;
    /**
     * Password to be used if the PostgreSQL server demands password authentication
     */
    readonly password: pulumi.Output<string | undefined>;
    readonly scheme: pulumi.Output<string | undefined>;
    /**
     * @deprecated Rename PostgreSQL provider `sslMode` attribute to `sslmode`
     */
    readonly sslMode: pulumi.Output<string | undefined>;
    /**
     * This option determines whether or with what priority a secure SSL TCP/IP connection will be negotiated with the
     * PostgreSQL server
     */
    readonly sslmode: pulumi.Output<string | undefined>;
    /**
     * The SSL server root certificate file path. The file must contain PEM encoded data.
     */
    readonly sslrootcert: pulumi.Output<string | undefined>;
    /**
     * PostgreSQL user name to connect as
     */
    readonly username: pulumi.Output<string | undefined>;
    /**
     * Create a Provider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProviderArgs, opts?: pulumi.ResourceOptions);
}
/**
 * The set of arguments for constructing a Provider resource.
 */
export interface ProviderArgs {
    /**
     * Use rdsIam instead of password authentication (see:
     * https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.html)
     */
    awsRdsIamAuth?: pulumi.Input<boolean>;
    /**
     * AWS profile to use for IAM auth
     */
    awsRdsIamProfile?: pulumi.Input<string>;
    /**
     * AWS region to use for IAM auth
     */
    awsRdsIamRegion?: pulumi.Input<string>;
    /**
     * Use MS Azure identity OAuth token (see:
     * https://learn.microsoft.com/en-us/azure/postgresql/flexible-server/how-to-configure-sign-in-azure-ad-authentication)
     */
    azureIdentityAuth?: pulumi.Input<boolean>;
    azureTenantId?: pulumi.Input<string>;
    /**
     * SSL client certificate if required by the database.
     */
    clientcert?: pulumi.Input<inputs.ProviderClientcert>;
    /**
     * Maximum wait for connection, in seconds. Zero or not specified means wait indefinitely.
     */
    connectTimeout?: pulumi.Input<number>;
    /**
     * The name of the database to connect to in order to conenct to (defaults to `postgres`).
     */
    database?: pulumi.Input<string>;
    /**
     * Database username associated to the connected user (for user name maps)
     */
    databaseUsername?: pulumi.Input<string>;
    /**
     * Specify the expected version of PostgreSQL.
     */
    expectedVersion?: pulumi.Input<string>;
    /**
     * Service account to impersonate when using GCP IAM authentication.
     */
    gcpIamImpersonateServiceAccount?: pulumi.Input<string>;
    /**
     * Name of PostgreSQL server address to connect to
     */
    host?: pulumi.Input<string>;
    /**
     * Maximum number of connections to establish to the database. Zero means unlimited.
     */
    maxConnections?: pulumi.Input<number>;
    /**
     * Password to be used if the PostgreSQL server demands password authentication
     */
    password?: pulumi.Input<string>;
    /**
     * The PostgreSQL port number to connect to at the server host, or socket file name extension for Unix-domain connections
     */
    port?: pulumi.Input<number>;
    scheme?: pulumi.Input<string>;
    /**
     * @deprecated Rename PostgreSQL provider `sslMode` attribute to `sslmode`
     */
    sslMode?: pulumi.Input<string>;
    /**
     * This option determines whether or with what priority a secure SSL TCP/IP connection will be negotiated with the
     * PostgreSQL server
     */
    sslmode?: pulumi.Input<string>;
    /**
     * The SSL server root certificate file path. The file must contain PEM encoded data.
     */
    sslrootcert?: pulumi.Input<string>;
    /**
     * Specify if the user to connect as is a Postgres superuser or not.If not, some feature might be disabled (e.g.:
     * Refreshing state password from Postgres)
     */
    superuser?: pulumi.Input<boolean>;
    /**
     * PostgreSQL user name to connect as
     */
    username?: pulumi.Input<string>;
}
